package VMOMI::HostProtocolEndpointProtocolEndpointType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
